@@ -61,6 +61,8 @@ TableHtmlRenderer <- R6::R6Class("TableHtmlRenderer",
      # get the dimensions of the table...
      rowCount <- private$p_parentTable$cells$rowCount
      columnCount <- private$p_parentTable$cells$columnCount
+     # compatibility to keep the explicit row/col span even if span is only 1
+     o2n <- !isTRUE(private$p_parentTable$compatibility$explicitHeaderSpansOfOne)
      # special case of no rows and no columns, return a blank empty table
      if((rowCount==0)&&(columnCount==0)) {
        tbl <- htmltools::tags$table(class=tableStyle, htmltools::tags$tr(
@@ -90,16 +92,40 @@ TableHtmlRenderer <- R6::R6Class("TableHtmlRenderer",
          cllstyl <- NULL
          if(!is.null(cell$style)) cllstyl <- cell$style$asCSSRule()
          # output the cell
-         if(cell$isMerged) {
-           mergeRange <- private$p_parentTable$mergedCells$ranges[[cell$mergeIndex]]
-           if(cell$visible) trow[[length(trow)+1]] <- htmltools::tags$td(rowspan=mergeRange$rSpan, colspan=mergeRange$cSpan,
-                                                                         class=cssCell, style=cllstyl, cell$formattedValue)
-           else trow[[length(trow)+1]] <- htmltools::tags$td(rowspan=mergeRange$rSpan, colspan=mergeRange$cSpan,
-                                                             class=cssCell, style=cllstyl) # todo: check escaping
+         renderAsTH <- (cell$cellType=="root") || (cell$cellType=="rowHeader") || (cell$cellType=="columnHeader")
+         renderAsTH <- renderAsTH && (!isTRUE(private$p_parentTable$compatibility$headerCellsAsTD))
+         if(renderAsTH)
+         {
+           # th cells
+           if(cell$isMerged) {
+             mergeRange <- private$p_parentTable$mergedCells$ranges[[cell$mergeIndex]]
+             if(cell$visible) trow[[length(trow)+1]] <- htmltools::tags$th(rowspan=oneToNULL(mergeRange$rSpan, o2n),
+                                                                           colspan=oneToNULL(mergeRange$cSpan, o2n),
+                                                                           class=cssCell, style=cllstyl, cell$fValueOrNBSP)
+             else trow[[length(trow)+1]] <- htmltools::tags$th(rowspan=oneToNULL(mergeRange$rSpan, o2n),
+                                                               colspan=oneToNULL(mergeRange$cSpan, o2n),
+                                                               class=cssCell, style=cllstyl) # todo: check escaping
+           }
+           else {
+             if(cell$visible) trow[[length(trow)+1]] <- htmltools::tags$th(class=cssCell, style=cllstyl, cell$fValueOrNBSP)
+             else trow[[length(trow)+1]] <- htmltools::tags$th(class=cssCell, style=cllstyl) # todo: check escaping
+           }
          }
          else {
-           if(cell$visible) trow[[length(trow)+1]] <- htmltools::tags$td(class=cssCell, style=cllstyl, cell$formattedValue)
-           else trow[[length(trow)+1]] <- htmltools::tags$td(class=cssCell, style=cllstyl) # todo: check escaping
+           # td cells
+           if(cell$isMerged) {
+             mergeRange <- private$p_parentTable$mergedCells$ranges[[cell$mergeIndex]]
+             if(cell$visible) trow[[length(trow)+1]] <- htmltools::tags$td(rowspan=oneToNULL(mergeRange$rSpan, o2n),
+                                                                           colspan=oneToNULL(mergeRange$cSpan, o2n),
+                                                                           class=cssCell, style=cllstyl, cell$fValueOrNBSP)
+             else trow[[length(trow)+1]] <- htmltools::tags$td(rowspan=oneToNULL(mergeRange$rSpan, o2n),
+                                                               colspan=oneToNULL(mergeRange$cSpan, o2n),
+                                                               class=cssCell, style=cllstyl) # todo: check escaping
+           }
+           else {
+             if(cell$visible) trow[[length(trow)+1]] <- htmltools::tags$td(class=cssCell, style=cllstyl, cell$fValueOrNBSP)
+             else trow[[length(trow)+1]] <- htmltools::tags$td(class=cssCell, style=cllstyl) # todo: check escaping
+           }
          }
        }
        # finished this row
